@@ -152,30 +152,31 @@ class _Project(_Base):
                 'filename':  file_name,
                 'datasourceKey': datasource_key
             }
-            upload_url = self._make_request('GET', f'/projects/{self.key}/models/presigned-url', params=params)['uploadUrl']
+            upload_url = self._make_request('GET', f'/projects/{self.key}/models/presigned-url', params=params)['url']
             requests.put(upload_url, data=f.read())
 
             self._make_request('POST', url)
 
-    def pull_model(self, filepath, datasource_key=None, round=None, federated_model=None, throw_error=False):
-        params = {}
+    def pull_model(self, filepath, datasource_key=None, round=None, federated_model=None):
+        params = {
+            'usePresignedUrl': True
+        }
         if round is not None:
             params['round'] = round
         if federated_model is not None:
             params['federatedModel'] = federated_model
 
         if datasource_key is None:
-            url = f'{self._get_route()}/projects/{self.key}/models'
+            url = f'/projects/{self.key}/models'
         else:
-            url = f'{self._get_route()}/projects/{self.key}/models/{datasource_key}'
-        r = requests.get(url, headers=self._get_headers(), params=params)
-        _check_for_error(r)
-
+            url = f'/projects/{self.key}/models/{datasource_key}'
+        download_url = self._make_request('GET', url, params=params)['url']
         directory = os.path.dirname(filepath)
         pathlib.Path(directory).mkdir(parents=True, exist_ok=True)
 
+        r = requests.get(download_url, stream=True)
         with open(filepath, 'wb') as f:
-            for chunk in r.iter_content(chunk_size=8192): 
+            for chunk in r.iter_content(chunk_size=None): 
                 f.write(chunk)
 
     def add_datasource_and_trainer(self, datasource_key, trainer_key, hyper_param_values={}):
